==> igniteui-react-core-18.2.0-beta.2.tgz: package/esm5/lib/BarFragmentDescriptionMetadata.js <==
/*
THIS INFRAGISTICS ULTIMATE SOFTWARE LICENSE  AGREEMENT ("AGREEMENT") LOCATED HERE:
https://www.infragistics.com/legal/license/igultimate-la
https://www.infragistics.com/legal/license/igultimate-eula
GOVERNS THE LICENSING, INSTALLATION AND USE OF INFRAGISTICS SOFTWARE. BY DOWNLOADING AND/OR INSTALLING AND USING INFRAGISTICS SOFTWARE:  you are indicating that you have read and understand this Agreement, and agree to be legally bound by it on behalf of the yourself and your company.
*/
import { __extends } from "tslib";
import { Base, String_$type, markType } from "./type";
import { Dictionary$2 } from "./Dictionary$2";
import { ColumnFragmentDescriptionMetadata } from "./ColumnFragmentDescriptionMetadata";
import { BarFragmentDescription } from "./BarFragmentDescription";
/**
 * @hidden
 */
var BarFragmentDescriptionMetadata = /** @class */ /*@__PURE__*/ (function (_super) {
    __extends(BarFragmentDescriptionMetadata, _super);
    function BarFragmentDescriptionMetadata() {
        return _super !== null && _super.apply(this, arguments) || this;
    }
    BarFragmentDescriptionMetadata.b = function (a) {
        if (BarFragmentDescriptionMetadata.a == null) {
            BarFragmentDescriptionMetadata.a = new Dictionary$2(String_$type, String_$type, 0);
            BarFragmentDescriptionMetadata.c(BarFragmentDescriptionMetadata.a);
        }
        if (a.k(BarFragmentDescriptionMetadata.a)) {
            return;
        }
        a.ab(BarFragmentDescriptionMetadata.a);
    };
    BarFragmentDescriptionMetadata.c = function (a) {
        ColumnFragmentDescriptionMetadata.c(a);
    };
    BarFragmentDescriptionMetadata.d = function (a) {
        BarFragmentDescriptionMetadata.b(a);
        a.ad("BarFragment", function () { return new BarFragmentDescription(); });
        a.ac("BarFragment", BarFragmentDescriptionMetadata.a);
    };
    BarFragmentDescriptionMetadata.$t = markType(BarFragmentDescriptionMetadata, 'BarFragmentDescriptionMetadata');
    BarFragmentDescriptionMetadata.a = null;
    return BarFragmentDescriptionMetadata;
}(Base));
export { BarFragmentDescriptionMetadata };

==> igniteui-react-core-18.7.5-beta.2.tgz: package/esm5/lib/BarFragmentDescriptionMetadata.js <==
/*
THIS INFRAGISTICS ULTIMATE SOFTWARE LICENSE  AGREEMENT ("AGREEMENT") LOCATED HERE:
https://www.infragistics.com/legal/license/igultimate-la
https://www.infragistics.com/legal/license/igultimate-eula
GOVERNS THE LICENSING, INSTALLATION AND USE OF INFRAGISTICS SOFTWARE. BY DOWNLOADING AND/OR INSTALLING AND USING INFRAGISTICS SOFTWARE:  you are indicating that you have read and understand this Agreement, and agree to be legally bound by it on behalf of the yourself and your company.
*/
import { __extends } from "tslib";
import { Base, String_$type, markType } from "./type";
import { Dictionary$2 } from "./Dictionary$2";
import { ColumnFragmentDescriptionMetadata } from "./ColumnFragmentDescriptionMetadata";
import { BarFragmentDescription } from "./BarFragmentDescription";
/**
 * @hidden
 */
var BarFragmentDescriptionMetadata = /** @class */ /*@__PURE__*/ (function (_super) {
    __extends(BarFragmentDescriptionMetadata, _super);
    function BarFragmentDescriptionMetadata() {
        return _super !== null && _super.apply(this, arguments) || this;
    }
    BarFragmentDescriptionMetadata.b = function (a) {
        if (BarFragmentDescriptionMetadata.a == null) {
            BarFragmentDescriptionMetadata.a = new Dictionary$2(String_$type, String_$type, 0);
            BarFragmentDescriptionMetadata.c(BarFragmentDescriptionMetadata.a);
        }
        if (a.k(BarFragmentDescriptionMetadata.a)) {
            return;
        }
        a.ac(BarFragmentDescriptionMetadata.a);
    };
    BarFragmentDescriptionMetadata.c = function (a) {
        ColumnFragmentDescriptionMetadata.c(a);
    };
    BarFragmentDescriptionMetadata.d = function (a) {
        BarFragmentDescriptionMetadata.b(a);
        a.ae("BarFragment", function () { return new BarFragmentDescription(); });
        a.ad("BarFragment", BarFragmentDescriptionMetadata.a);
    };
    BarFragmentDescriptionMetadata.$t = markType(BarFragmentDescriptionMetadata, 'BarFragmentDescriptionMetadata');
    BarFragmentDescriptionMetadata.a = null;
    return BarFragmentDescriptionMetadata;
}(Base));
export { BarFragmentDescriptionMetadata };
